#ifndef K3BPLUGIN_I18N_H
#define K3BPLUGIN_I18N_H

#define TRANSLATION_DOMAIN "k3b"
#include <KLocalizedString>

#endif // K3BPLUGIN_I18N_H
